from distutils.core import setup
setup(
        name='haha',
        version='100.0.0',
        py_modules=['haha'],
        author='zhaimingyu',
        author_email='25839401@163.com',
        url='www.baidu.com',
        description='you are a bird',
     )
